# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetBillingGroupResult',
    'AwaitableGetBillingGroupResult',
    'get_billing_group',
    'get_billing_group_output',
]

@pulumi.output_type
class GetBillingGroupResult:
    """
    A collection of values returned by getBillingGroup.
    """
    def __init__(__self__, account_id=None, address_lines=None, billing_currency=None, billing_emails=None, billing_extra_text=None, billing_group_id=None, card_id=None, city=None, company=None, copy_from_billing_group=None, country_code=None, id=None, name=None, parent_id=None, state=None, vat_id=None, zip_code=None):
        if account_id and not isinstance(account_id, str):
            raise TypeError("Expected argument 'account_id' to be a str")
        pulumi.set(__self__, "account_id", account_id)
        if address_lines and not isinstance(address_lines, list):
            raise TypeError("Expected argument 'address_lines' to be a list")
        pulumi.set(__self__, "address_lines", address_lines)
        if billing_currency and not isinstance(billing_currency, str):
            raise TypeError("Expected argument 'billing_currency' to be a str")
        pulumi.set(__self__, "billing_currency", billing_currency)
        if billing_emails and not isinstance(billing_emails, list):
            raise TypeError("Expected argument 'billing_emails' to be a list")
        pulumi.set(__self__, "billing_emails", billing_emails)
        if billing_extra_text and not isinstance(billing_extra_text, str):
            raise TypeError("Expected argument 'billing_extra_text' to be a str")
        pulumi.set(__self__, "billing_extra_text", billing_extra_text)
        if billing_group_id and not isinstance(billing_group_id, str):
            raise TypeError("Expected argument 'billing_group_id' to be a str")
        pulumi.set(__self__, "billing_group_id", billing_group_id)
        if card_id and not isinstance(card_id, str):
            raise TypeError("Expected argument 'card_id' to be a str")
        pulumi.set(__self__, "card_id", card_id)
        if city and not isinstance(city, str):
            raise TypeError("Expected argument 'city' to be a str")
        pulumi.set(__self__, "city", city)
        if company and not isinstance(company, str):
            raise TypeError("Expected argument 'company' to be a str")
        pulumi.set(__self__, "company", company)
        if copy_from_billing_group and not isinstance(copy_from_billing_group, str):
            raise TypeError("Expected argument 'copy_from_billing_group' to be a str")
        pulumi.set(__self__, "copy_from_billing_group", copy_from_billing_group)
        if country_code and not isinstance(country_code, str):
            raise TypeError("Expected argument 'country_code' to be a str")
        pulumi.set(__self__, "country_code", country_code)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if parent_id and not isinstance(parent_id, str):
            raise TypeError("Expected argument 'parent_id' to be a str")
        pulumi.set(__self__, "parent_id", parent_id)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if vat_id and not isinstance(vat_id, str):
            raise TypeError("Expected argument 'vat_id' to be a str")
        pulumi.set(__self__, "vat_id", vat_id)
        if zip_code and not isinstance(zip_code, str):
            raise TypeError("Expected argument 'zip_code' to be a str")
        pulumi.set(__self__, "zip_code", zip_code)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> str:
        """
        Account ID.
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter(name="addressLines")
    def address_lines(self) -> Sequence[str]:
        """
        Address lines 1 and 2. For example, street, PO box, or building.
        """
        return pulumi.get(self, "address_lines")

    @property
    @pulumi.getter(name="billingCurrency")
    def billing_currency(self) -> str:
        """
        Billing currency for the billing group. Supported currencies are: AUD, CAD, CHF, DKK, EUR, GBP, JPY, NOK, NZD, SEK, SGD, and USD.
        """
        return pulumi.get(self, "billing_currency")

    @property
    @pulumi.getter(name="billingEmails")
    def billing_emails(self) -> Sequence[str]:
        """
        Email address of billing contacts. Invoices and other payment notifications are emailed to all billing contacts.
        """
        return pulumi.get(self, "billing_emails")

    @property
    @pulumi.getter(name="billingExtraText")
    def billing_extra_text(self) -> str:
        """
        Additional information to include on your invoice (for example, a reference number).
        """
        return pulumi.get(self, "billing_extra_text")

    @property
    @pulumi.getter(name="billingGroupId")
    def billing_group_id(self) -> str:
        """
        The ID of the billing group. To set up proper dependencies please refer to this variable as a reference.
        """
        return pulumi.get(self, "billing_group_id")

    @property
    @pulumi.getter(name="cardId")
    def card_id(self) -> str:
        """
        Credit card ID.
        """
        return pulumi.get(self, "card_id")

    @property
    @pulumi.getter
    def city(self) -> str:
        """
        City, district, suburb, town, or village.
        """
        return pulumi.get(self, "city")

    @property
    @pulumi.getter
    def company(self) -> str:
        """
        Your company name.
        """
        return pulumi.get(self, "company")

    @property
    @pulumi.getter(name="copyFromBillingGroup")
    def copy_from_billing_group(self) -> str:
        """
        ID of the billing group to copy the company name, address, currency, billing contacts, and extra text from.
        """
        return pulumi.get(self, "copy_from_billing_group")

    @property
    @pulumi.getter(name="countryCode")
    def country_code(self) -> str:
        """
        Two-letter country code.
        """
        return pulumi.get(self, "country_code")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        Name of the billing group.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="parentId")
    def parent_id(self) -> str:
        """
        Link a billing group to an existing organization by using its ID. To set up proper dependencies please refer to this variable as a reference.
        """
        return pulumi.get(self, "parent_id")

    @property
    @pulumi.getter
    def state(self) -> str:
        """
        Address state.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="vatId")
    def vat_id(self) -> str:
        """
        The VAT identification number for your company.
        """
        return pulumi.get(self, "vat_id")

    @property
    @pulumi.getter(name="zipCode")
    def zip_code(self) -> str:
        """
        Zip or postal code.
        """
        return pulumi.get(self, "zip_code")


class AwaitableGetBillingGroupResult(GetBillingGroupResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetBillingGroupResult(
            account_id=self.account_id,
            address_lines=self.address_lines,
            billing_currency=self.billing_currency,
            billing_emails=self.billing_emails,
            billing_extra_text=self.billing_extra_text,
            billing_group_id=self.billing_group_id,
            card_id=self.card_id,
            city=self.city,
            company=self.company,
            copy_from_billing_group=self.copy_from_billing_group,
            country_code=self.country_code,
            id=self.id,
            name=self.name,
            parent_id=self.parent_id,
            state=self.state,
            vat_id=self.vat_id,
            zip_code=self.zip_code)


def get_billing_group(billing_group_id: Optional[str] = None,
                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetBillingGroupResult:
    """
    Gets information about a billing group.


    :param str billing_group_id: The ID of the billing group. To set up proper dependencies please refer to this variable as a reference.
    """
    __args__ = dict()
    __args__['billingGroupId'] = billing_group_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('aiven:index/getBillingGroup:getBillingGroup', __args__, opts=opts, typ=GetBillingGroupResult).value

    return AwaitableGetBillingGroupResult(
        account_id=pulumi.get(__ret__, 'account_id'),
        address_lines=pulumi.get(__ret__, 'address_lines'),
        billing_currency=pulumi.get(__ret__, 'billing_currency'),
        billing_emails=pulumi.get(__ret__, 'billing_emails'),
        billing_extra_text=pulumi.get(__ret__, 'billing_extra_text'),
        billing_group_id=pulumi.get(__ret__, 'billing_group_id'),
        card_id=pulumi.get(__ret__, 'card_id'),
        city=pulumi.get(__ret__, 'city'),
        company=pulumi.get(__ret__, 'company'),
        copy_from_billing_group=pulumi.get(__ret__, 'copy_from_billing_group'),
        country_code=pulumi.get(__ret__, 'country_code'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        parent_id=pulumi.get(__ret__, 'parent_id'),
        state=pulumi.get(__ret__, 'state'),
        vat_id=pulumi.get(__ret__, 'vat_id'),
        zip_code=pulumi.get(__ret__, 'zip_code'))
def get_billing_group_output(billing_group_id: Optional[pulumi.Input[str]] = None,
                             opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetBillingGroupResult]:
    """
    Gets information about a billing group.


    :param str billing_group_id: The ID of the billing group. To set up proper dependencies please refer to this variable as a reference.
    """
    __args__ = dict()
    __args__['billingGroupId'] = billing_group_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('aiven:index/getBillingGroup:getBillingGroup', __args__, opts=opts, typ=GetBillingGroupResult)
    return __ret__.apply(lambda __response__: GetBillingGroupResult(
        account_id=pulumi.get(__response__, 'account_id'),
        address_lines=pulumi.get(__response__, 'address_lines'),
        billing_currency=pulumi.get(__response__, 'billing_currency'),
        billing_emails=pulumi.get(__response__, 'billing_emails'),
        billing_extra_text=pulumi.get(__response__, 'billing_extra_text'),
        billing_group_id=pulumi.get(__response__, 'billing_group_id'),
        card_id=pulumi.get(__response__, 'card_id'),
        city=pulumi.get(__response__, 'city'),
        company=pulumi.get(__response__, 'company'),
        copy_from_billing_group=pulumi.get(__response__, 'copy_from_billing_group'),
        country_code=pulumi.get(__response__, 'country_code'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        parent_id=pulumi.get(__response__, 'parent_id'),
        state=pulumi.get(__response__, 'state'),
        vat_id=pulumi.get(__response__, 'vat_id'),
        zip_code=pulumi.get(__response__, 'zip_code')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetServiceIntegrationEndpointResult',
    'AwaitableGetServiceIntegrationEndpointResult',
    'get_service_integration_endpoint',
    'get_service_integration_endpoint_output',
]

@pulumi.output_type
class GetServiceIntegrationEndpointResult:
    """
    A collection of values returned by getServiceIntegrationEndpoint.
    """
    def __init__(__self__, autoscaler_user_configs=None, datadog_user_configs=None, endpoint_config=None, endpoint_name=None, endpoint_type=None, external_aws_cloudwatch_logs_user_configs=None, external_aws_cloudwatch_metrics_user_configs=None, external_aws_s3_user_configs=None, external_azure_blob_storage_user_configs=None, external_clickhouse_user_configs=None, external_elasticsearch_logs_user_configs=None, external_google_cloud_bigqueries=None, external_google_cloud_logging_user_configs=None, external_kafka_user_configs=None, external_mysql_user_configs=None, external_opensearch_logs_user_configs=None, external_postgresqls=None, external_prometheus_user_configs=None, external_schema_registry_user_configs=None, id=None, jolokia_user_configs=None, project=None, prometheus_user_configs=None, rsyslog_user_configs=None):
        if autoscaler_user_configs and not isinstance(autoscaler_user_configs, list):
            raise TypeError("Expected argument 'autoscaler_user_configs' to be a list")
        pulumi.set(__self__, "autoscaler_user_configs", autoscaler_user_configs)
        if datadog_user_configs and not isinstance(datadog_user_configs, list):
            raise TypeError("Expected argument 'datadog_user_configs' to be a list")
        pulumi.set(__self__, "datadog_user_configs", datadog_user_configs)
        if endpoint_config and not isinstance(endpoint_config, dict):
            raise TypeError("Expected argument 'endpoint_config' to be a dict")
        pulumi.set(__self__, "endpoint_config", endpoint_config)
        if endpoint_name and not isinstance(endpoint_name, str):
            raise TypeError("Expected argument 'endpoint_name' to be a str")
        pulumi.set(__self__, "endpoint_name", endpoint_name)
        if endpoint_type and not isinstance(endpoint_type, str):
            raise TypeError("Expected argument 'endpoint_type' to be a str")
        pulumi.set(__self__, "endpoint_type", endpoint_type)
        if external_aws_cloudwatch_logs_user_configs and not isinstance(external_aws_cloudwatch_logs_user_configs, list):
            raise TypeError("Expected argument 'external_aws_cloudwatch_logs_user_configs' to be a list")
        pulumi.set(__self__, "external_aws_cloudwatch_logs_user_configs", external_aws_cloudwatch_logs_user_configs)
        if external_aws_cloudwatch_metrics_user_configs and not isinstance(external_aws_cloudwatch_metrics_user_configs, list):
            raise TypeError("Expected argument 'external_aws_cloudwatch_metrics_user_configs' to be a list")
        pulumi.set(__self__, "external_aws_cloudwatch_metrics_user_configs", external_aws_cloudwatch_metrics_user_configs)
        if external_aws_s3_user_configs and not isinstance(external_aws_s3_user_configs, list):
            raise TypeError("Expected argument 'external_aws_s3_user_configs' to be a list")
        pulumi.set(__self__, "external_aws_s3_user_configs", external_aws_s3_user_configs)
        if external_azure_blob_storage_user_configs and not isinstance(external_azure_blob_storage_user_configs, list):
            raise TypeError("Expected argument 'external_azure_blob_storage_user_configs' to be a list")
        pulumi.set(__self__, "external_azure_blob_storage_user_configs", external_azure_blob_storage_user_configs)
        if external_clickhouse_user_configs and not isinstance(external_clickhouse_user_configs, list):
            raise TypeError("Expected argument 'external_clickhouse_user_configs' to be a list")
        pulumi.set(__self__, "external_clickhouse_user_configs", external_clickhouse_user_configs)
        if external_elasticsearch_logs_user_configs and not isinstance(external_elasticsearch_logs_user_configs, list):
            raise TypeError("Expected argument 'external_elasticsearch_logs_user_configs' to be a list")
        pulumi.set(__self__, "external_elasticsearch_logs_user_configs", external_elasticsearch_logs_user_configs)
        if external_google_cloud_bigqueries and not isinstance(external_google_cloud_bigqueries, list):
            raise TypeError("Expected argument 'external_google_cloud_bigqueries' to be a list")
        pulumi.set(__self__, "external_google_cloud_bigqueries", external_google_cloud_bigqueries)
        if external_google_cloud_logging_user_configs and not isinstance(external_google_cloud_logging_user_configs, list):
            raise TypeError("Expected argument 'external_google_cloud_logging_user_configs' to be a list")
        pulumi.set(__self__, "external_google_cloud_logging_user_configs", external_google_cloud_logging_user_configs)
        if external_kafka_user_configs and not isinstance(external_kafka_user_configs, list):
            raise TypeError("Expected argument 'external_kafka_user_configs' to be a list")
        pulumi.set(__self__, "external_kafka_user_configs", external_kafka_user_configs)
        if external_mysql_user_configs and not isinstance(external_mysql_user_configs, list):
            raise TypeError("Expected argument 'external_mysql_user_configs' to be a list")
        pulumi.set(__self__, "external_mysql_user_configs", external_mysql_user_configs)
        if external_opensearch_logs_user_configs and not isinstance(external_opensearch_logs_user_configs, list):
            raise TypeError("Expected argument 'external_opensearch_logs_user_configs' to be a list")
        pulumi.set(__self__, "external_opensearch_logs_user_configs", external_opensearch_logs_user_configs)
        if external_postgresqls and not isinstance(external_postgresqls, list):
            raise TypeError("Expected argument 'external_postgresqls' to be a list")
        pulumi.set(__self__, "external_postgresqls", external_postgresqls)
        if external_prometheus_user_configs and not isinstance(external_prometheus_user_configs, list):
            raise TypeError("Expected argument 'external_prometheus_user_configs' to be a list")
        pulumi.set(__self__, "external_prometheus_user_configs", external_prometheus_user_configs)
        if external_schema_registry_user_configs and not isinstance(external_schema_registry_user_configs, list):
            raise TypeError("Expected argument 'external_schema_registry_user_configs' to be a list")
        pulumi.set(__self__, "external_schema_registry_user_configs", external_schema_registry_user_configs)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if jolokia_user_configs and not isinstance(jolokia_user_configs, list):
            raise TypeError("Expected argument 'jolokia_user_configs' to be a list")
        pulumi.set(__self__, "jolokia_user_configs", jolokia_user_configs)
        if project and not isinstance(project, str):
            raise TypeError("Expected argument 'project' to be a str")
        pulumi.set(__self__, "project", project)
        if prometheus_user_configs and not isinstance(prometheus_user_configs, list):
            raise TypeError("Expected argument 'prometheus_user_configs' to be a list")
        pulumi.set(__self__, "prometheus_user_configs", prometheus_user_configs)
        if rsyslog_user_configs and not isinstance(rsyslog_user_configs, list):
            raise TypeError("Expected argument 'rsyslog_user_configs' to be a list")
        pulumi.set(__self__, "rsyslog_user_configs", rsyslog_user_configs)

    @property
    @pulumi.getter(name="autoscalerUserConfigs")
    def autoscaler_user_configs(self) -> Sequence['outputs.GetServiceIntegrationEndpointAutoscalerUserConfigResult']:
        """
        Autoscaler user configurable settings. **Warning:** There's no way to reset advanced configuration options to default. Options that you add cannot be removed later
        """
        return pulumi.get(self, "autoscaler_user_configs")

    @property
    @pulumi.getter(name="datadogUserConfigs")
    def datadog_user_configs(self) -> Sequence['outputs.GetServiceIntegrationEndpointDatadogUserConfigResult']:
        """
        Datadog user configurable settings. **Warning:** There's no way to reset advanced configuration options to default. Options that you add cannot be removed later
        """
        return pulumi.get(self, "datadog_user_configs")

    @property
    @pulumi.getter(name="endpointConfig")
    def endpoint_config(self) -> Mapping[str, str]:
        """
        Backend configuration for the endpoint.
        """
        return pulumi.get(self, "endpoint_config")

    @property
    @pulumi.getter(name="endpointName")
    def endpoint_name(self) -> str:
        """
        Name of the service integration endpoint.
        """
        return pulumi.get(self, "endpoint_name")

    @property
    @pulumi.getter(name="endpointType")
    def endpoint_type(self) -> str:
        """
        The type of service integration endpoint. The possible values are `autoscaler`, `datadog`, `external_aws_cloudwatch_logs`, `external_aws_cloudwatch_metrics`, `external_aws_s3`, `external_azure_blob_storage`, `external_clickhouse`, `external_elasticsearch_logs`, `external_google_cloud_bigquery`, `external_google_cloud_logging`, `external_kafka`, `external_mysql`, `external_opensearch_logs`, `external_postgresql`, `external_prometheus`, `external_redis`, `external_schema_registry`, `external_sumologic_logs`, `jolokia`, `prometheus` and `rsyslog`.
        """
        return pulumi.get(self, "endpoint_type")

    @property
    @pulumi.getter(name="externalAwsCloudwatchLogsUserConfigs")
    def external_aws_cloudwatch_logs_user_configs(self) -> Sequence['outputs.GetServiceIntegrationEndpointExternalAwsCloudwatchLogsUserConfigResult']:
        """
        ExternalAwsCloudwatchLogs user configurable settings. **Warning:** There's no way to reset advanced configuration options to default. Options that you add cannot be removed later
        """
        return pulumi.get(self, "external_aws_cloudwatch_logs_user_configs")

    @property
    @pulumi.getter(name="externalAwsCloudwatchMetricsUserConfigs")
    def external_aws_cloudwatch_metrics_user_configs(self) -> Sequence['outputs.GetServiceIntegrationEndpointExternalAwsCloudwatchMetricsUserConfigResult']:
        """
        ExternalAwsCloudwatchMetrics user configurable settings. **Warning:** There's no way to reset advanced configuration options to default. Options that you add cannot be removed later
        """
        return pulumi.get(self, "external_aws_cloudwatch_metrics_user_configs")

    @property
    @pulumi.getter(name="externalAwsS3UserConfigs")
    def external_aws_s3_user_configs(self) -> Sequence['outputs.GetServiceIntegrationEndpointExternalAwsS3UserConfigResult']:
        """
        ExternalAwsS3 user configurable settings. **Warning:** There's no way to reset advanced configuration options to default. Options that you add cannot be removed later
        """
        return pulumi.get(self, "external_aws_s3_user_configs")

    @property
    @pulumi.getter(name="externalAzureBlobStorageUserConfigs")
    def external_azure_blob_storage_user_configs(self) -> Sequence['outputs.GetServiceIntegrationEndpointExternalAzureBlobStorageUserConfigResult']:
        """
        ExternalAzureBlobStorage user configurable settings. **Warning:** There's no way to reset advanced configuration options to default. Options that you add cannot be removed later
        """
        return pulumi.get(self, "external_azure_blob_storage_user_configs")

    @property
    @pulumi.getter(name="externalClickhouseUserConfigs")
    def external_clickhouse_user_configs(self) -> Sequence['outputs.GetServiceIntegrationEndpointExternalClickhouseUserConfigResult']:
        """
        ExternalClickhouse user configurable settings. **Warning:** There's no way to reset advanced configuration options to default. Options that you add cannot be removed later
        """
        return pulumi.get(self, "external_clickhouse_user_configs")

    @property
    @pulumi.getter(name="externalElasticsearchLogsUserConfigs")
    def external_elasticsearch_logs_user_configs(self) -> Sequence['outputs.GetServiceIntegrationEndpointExternalElasticsearchLogsUserConfigResult']:
        """
        ExternalElasticsearchLogs user configurable settings. **Warning:** There's no way to reset advanced configuration options to default. Options that you add cannot be removed later
        """
        return pulumi.get(self, "external_elasticsearch_logs_user_configs")

    @property
    @pulumi.getter(name="externalGoogleCloudBigqueries")
    def external_google_cloud_bigqueries(self) -> Sequence['outputs.GetServiceIntegrationEndpointExternalGoogleCloudBigqueryResult']:
        """
        ExternalGoogleCloudBigquery user configurable settings. **Warning:** There's no way to reset advanced configuration options to default. Options that you add cannot be removed later
        """
        return pulumi.get(self, "external_google_cloud_bigqueries")

    @property
    @pulumi.getter(name="externalGoogleCloudLoggingUserConfigs")
    def external_google_cloud_logging_user_configs(self) -> Sequence['outputs.GetServiceIntegrationEndpointExternalGoogleCloudLoggingUserConfigResult']:
        """
        ExternalGoogleCloudLogging user configurable settings. **Warning:** There's no way to reset advanced configuration options to default. Options that you add cannot be removed later
        """
        return pulumi.get(self, "external_google_cloud_logging_user_configs")

    @property
    @pulumi.getter(name="externalKafkaUserConfigs")
    def external_kafka_user_configs(self) -> Sequence['outputs.GetServiceIntegrationEndpointExternalKafkaUserConfigResult']:
        """
        ExternalKafka user configurable settings. **Warning:** There's no way to reset advanced configuration options to default. Options that you add cannot be removed later
        """
        return pulumi.get(self, "external_kafka_user_configs")

    @property
    @pulumi.getter(name="externalMysqlUserConfigs")
    def external_mysql_user_configs(self) -> Sequence['outputs.GetServiceIntegrationEndpointExternalMysqlUserConfigResult']:
        """
        ExternalMysql user configurable settings. **Warning:** There's no way to reset advanced configuration options to default. Options that you add cannot be removed later
        """
        return pulumi.get(self, "external_mysql_user_configs")

    @property
    @pulumi.getter(name="externalOpensearchLogsUserConfigs")
    def external_opensearch_logs_user_configs(self) -> Sequence['outputs.GetServiceIntegrationEndpointExternalOpensearchLogsUserConfigResult']:
        """
        ExternalOpensearchLogs user configurable settings. **Warning:** There's no way to reset advanced configuration options to default. Options that you add cannot be removed later
        """
        return pulumi.get(self, "external_opensearch_logs_user_configs")

    @property
    @pulumi.getter(name="externalPostgresqls")
    def external_postgresqls(self) -> Sequence['outputs.GetServiceIntegrationEndpointExternalPostgresqlResult']:
        """
        ExternalPostgresql user configurable settings. **Warning:** There's no way to reset advanced configuration options to default. Options that you add cannot be removed later
        """
        return pulumi.get(self, "external_postgresqls")

    @property
    @pulumi.getter(name="externalPrometheusUserConfigs")
    def external_prometheus_user_configs(self) -> Sequence['outputs.GetServiceIntegrationEndpointExternalPrometheusUserConfigResult']:
        """
        ExternalPrometheus user configurable settings. **Warning:** There's no way to reset advanced configuration options to default. Options that you add cannot be removed later
        """
        return pulumi.get(self, "external_prometheus_user_configs")

    @property
    @pulumi.getter(name="externalSchemaRegistryUserConfigs")
    def external_schema_registry_user_configs(self) -> Sequence['outputs.GetServiceIntegrationEndpointExternalSchemaRegistryUserConfigResult']:
        """
        ExternalSchemaRegistry user configurable settings. **Warning:** There's no way to reset advanced configuration options to default. Options that you add cannot be removed later
        """
        return pulumi.get(self, "external_schema_registry_user_configs")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="jolokiaUserConfigs")
    def jolokia_user_configs(self) -> Sequence['outputs.GetServiceIntegrationEndpointJolokiaUserConfigResult']:
        """
        Jolokia user configurable settings. **Warning:** There's no way to reset advanced configuration options to default. Options that you add cannot be removed later
        """
        return pulumi.get(self, "jolokia_user_configs")

    @property
    @pulumi.getter
    def project(self) -> str:
        """
        Project the service integration endpoint is in.
        """
        return pulumi.get(self, "project")

    @property
    @pulumi.getter(name="prometheusUserConfigs")
    def prometheus_user_configs(self) -> Sequence['outputs.GetServiceIntegrationEndpointPrometheusUserConfigResult']:
        """
        Prometheus user configurable settings. **Warning:** There's no way to reset advanced configuration options to default. Options that you add cannot be removed later
        """
        return pulumi.get(self, "prometheus_user_configs")

    @property
    @pulumi.getter(name="rsyslogUserConfigs")
    def rsyslog_user_configs(self) -> Sequence['outputs.GetServiceIntegrationEndpointRsyslogUserConfigResult']:
        """
        Rsyslog user configurable settings. **Warning:** There's no way to reset advanced configuration options to default. Options that you add cannot be removed later
        """
        return pulumi.get(self, "rsyslog_user_configs")


class AwaitableGetServiceIntegrationEndpointResult(GetServiceIntegrationEndpointResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetServiceIntegrationEndpointResult(
            autoscaler_user_configs=self.autoscaler_user_configs,
            datadog_user_configs=self.datadog_user_configs,
            endpoint_config=self.endpoint_config,
            endpoint_name=self.endpoint_name,
            endpoint_type=self.endpoint_type,
            external_aws_cloudwatch_logs_user_configs=self.external_aws_cloudwatch_logs_user_configs,
            external_aws_cloudwatch_metrics_user_configs=self.external_aws_cloudwatch_metrics_user_configs,
            external_aws_s3_user_configs=self.external_aws_s3_user_configs,
            external_azure_blob_storage_user_configs=self.external_azure_blob_storage_user_configs,
            external_clickhouse_user_configs=self.external_clickhouse_user_configs,
            external_elasticsearch_logs_user_configs=self.external_elasticsearch_logs_user_configs,
            external_google_cloud_bigqueries=self.external_google_cloud_bigqueries,
            external_google_cloud_logging_user_configs=self.external_google_cloud_logging_user_configs,
            external_kafka_user_configs=self.external_kafka_user_configs,
            external_mysql_user_configs=self.external_mysql_user_configs,
            external_opensearch_logs_user_configs=self.external_opensearch_logs_user_configs,
            external_postgresqls=self.external_postgresqls,
            external_prometheus_user_configs=self.external_prometheus_user_configs,
            external_schema_registry_user_configs=self.external_schema_registry_user_configs,
            id=self.id,
            jolokia_user_configs=self.jolokia_user_configs,
            project=self.project,
            prometheus_user_configs=self.prometheus_user_configs,
            rsyslog_user_configs=self.rsyslog_user_configs)


def get_service_integration_endpoint(endpoint_name: Optional[str] = None,
                                     project: Optional[str] = None,
                                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetServiceIntegrationEndpointResult:
    """
    Gets information about an integration endpoint.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_aiven as aiven

    example_datadog_endpoint = aiven.get_service_integration_endpoint(project=example_project["project"],
        endpoint_name="Datadog endpoint")
    ```


    :param str endpoint_name: Name of the service integration endpoint.
    :param str project: Project the service integration endpoint is in.
    """
    __args__ = dict()
    __args__['endpointName'] = endpoint_name
    __args__['project'] = project
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('aiven:index/getServiceIntegrationEndpoint:getServiceIntegrationEndpoint', __args__, opts=opts, typ=GetServiceIntegrationEndpointResult).value

    return AwaitableGetServiceIntegrationEndpointResult(
        autoscaler_user_configs=pulumi.get(__ret__, 'autoscaler_user_configs'),
        datadog_user_configs=pulumi.get(__ret__, 'datadog_user_configs'),
        endpoint_config=pulumi.get(__ret__, 'endpoint_config'),
        endpoint_name=pulumi.get(__ret__, 'endpoint_name'),
        endpoint_type=pulumi.get(__ret__, 'endpoint_type'),
        external_aws_cloudwatch_logs_user_configs=pulumi.get(__ret__, 'external_aws_cloudwatch_logs_user_configs'),
        external_aws_cloudwatch_metrics_user_configs=pulumi.get(__ret__, 'external_aws_cloudwatch_metrics_user_configs'),
        external_aws_s3_user_configs=pulumi.get(__ret__, 'external_aws_s3_user_configs'),
        external_azure_blob_storage_user_configs=pulumi.get(__ret__, 'external_azure_blob_storage_user_configs'),
        external_clickhouse_user_configs=pulumi.get(__ret__, 'external_clickhouse_user_configs'),
        external_elasticsearch_logs_user_configs=pulumi.get(__ret__, 'external_elasticsearch_logs_user_configs'),
        external_google_cloud_bigqueries=pulumi.get(__ret__, 'external_google_cloud_bigqueries'),
        external_google_cloud_logging_user_configs=pulumi.get(__ret__, 'external_google_cloud_logging_user_configs'),
        external_kafka_user_configs=pulumi.get(__ret__, 'external_kafka_user_configs'),
        external_mysql_user_configs=pulumi.get(__ret__, 'external_mysql_user_configs'),
        external_opensearch_logs_user_configs=pulumi.get(__ret__, 'external_opensearch_logs_user_configs'),
        external_postgresqls=pulumi.get(__ret__, 'external_postgresqls'),
        external_prometheus_user_configs=pulumi.get(__ret__, 'external_prometheus_user_configs'),
        external_schema_registry_user_configs=pulumi.get(__ret__, 'external_schema_registry_user_configs'),
        id=pulumi.get(__ret__, 'id'),
        jolokia_user_configs=pulumi.get(__ret__, 'jolokia_user_configs'),
        project=pulumi.get(__ret__, 'project'),
        prometheus_user_configs=pulumi.get(__ret__, 'prometheus_user_configs'),
        rsyslog_user_configs=pulumi.get(__ret__, 'rsyslog_user_configs'))
def get_service_integration_endpoint_output(endpoint_name: Optional[pulumi.Input[str]] = None,
                                            project: Optional[pulumi.Input[str]] = None,
                                            opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetServiceIntegrationEndpointResult]:
    """
    Gets information about an integration endpoint.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_aiven as aiven

    example_datadog_endpoint = aiven.get_service_integration_endpoint(project=example_project["project"],
        endpoint_name="Datadog endpoint")
    ```


    :param str endpoint_name: Name of the service integration endpoint.
    :param str project: Project the service integration endpoint is in.
    """
    __args__ = dict()
    __args__['endpointName'] = endpoint_name
    __args__['project'] = project
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('aiven:index/getServiceIntegrationEndpoint:getServiceIntegrationEndpoint', __args__, opts=opts, typ=GetServiceIntegrationEndpointResult)
    return __ret__.apply(lambda __response__: GetServiceIntegrationEndpointResult(
        autoscaler_user_configs=pulumi.get(__response__, 'autoscaler_user_configs'),
        datadog_user_configs=pulumi.get(__response__, 'datadog_user_configs'),
        endpoint_config=pulumi.get(__response__, 'endpoint_config'),
        endpoint_name=pulumi.get(__response__, 'endpoint_name'),
        endpoint_type=pulumi.get(__response__, 'endpoint_type'),
        external_aws_cloudwatch_logs_user_configs=pulumi.get(__response__, 'external_aws_cloudwatch_logs_user_configs'),
        external_aws_cloudwatch_metrics_user_configs=pulumi.get(__response__, 'external_aws_cloudwatch_metrics_user_configs'),
        external_aws_s3_user_configs=pulumi.get(__response__, 'external_aws_s3_user_configs'),
        external_azure_blob_storage_user_configs=pulumi.get(__response__, 'external_azure_blob_storage_user_configs'),
        external_clickhouse_user_configs=pulumi.get(__response__, 'external_clickhouse_user_configs'),
        external_elasticsearch_logs_user_configs=pulumi.get(__response__, 'external_elasticsearch_logs_user_configs'),
        external_google_cloud_bigqueries=pulumi.get(__response__, 'external_google_cloud_bigqueries'),
        external_google_cloud_logging_user_configs=pulumi.get(__response__, 'external_google_cloud_logging_user_configs'),
        external_kafka_user_configs=pulumi.get(__response__, 'external_kafka_user_configs'),
        external_mysql_user_configs=pulumi.get(__response__, 'external_mysql_user_configs'),
        external_opensearch_logs_user_configs=pulumi.get(__response__, 'external_opensearch_logs_user_configs'),
        external_postgresqls=pulumi.get(__response__, 'external_postgresqls'),
        external_prometheus_user_configs=pulumi.get(__response__, 'external_prometheus_user_configs'),
        external_schema_registry_user_configs=pulumi.get(__response__, 'external_schema_registry_user_configs'),
        id=pulumi.get(__response__, 'id'),
        jolokia_user_configs=pulumi.get(__response__, 'jolokia_user_configs'),
        project=pulumi.get(__response__, 'project'),
        prometheus_user_configs=pulumi.get(__response__, 'prometheus_user_configs'),
        rsyslog_user_configs=pulumi.get(__response__, 'rsyslog_user_configs')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['OrganizationArgs', 'Organization']

@pulumi.input_type
class OrganizationArgs:
    def __init__(__self__, *,
                 name: Optional[pulumi.Input[str]] = None,
                 timeouts: Optional[pulumi.Input['OrganizationTimeoutsArgs']] = None):
        """
        The set of arguments for constructing a Organization resource.
        :param pulumi.Input[str] name: Name of the organization.
        """
        if name is not None:
            pulumi.set(__self__, "name", name)
        if timeouts is not None:
            pulumi.set(__self__, "timeouts", timeouts)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the organization.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def timeouts(self) -> Optional[pulumi.Input['OrganizationTimeoutsArgs']]:
        return pulumi.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: Optional[pulumi.Input['OrganizationTimeoutsArgs']]):
        pulumi.set(self, "timeouts", value)


@pulumi.input_type
class _OrganizationState:
    def __init__(__self__, *,
                 create_time: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 tenant_id: Optional[pulumi.Input[str]] = None,
                 timeouts: Optional[pulumi.Input['OrganizationTimeoutsArgs']] = None,
                 update_time: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Organization resources.
        :param pulumi.Input[str] create_time: Timestamp of the creation of the organization.
        :param pulumi.Input[str] name: Name of the organization.
        :param pulumi.Input[str] tenant_id: Tenant ID of the organization.
        :param pulumi.Input[str] update_time: Timestamp of the last update of the organization.
        """
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if tenant_id is not None:
            pulumi.set(__self__, "tenant_id", tenant_id)
        if timeouts is not None:
            pulumi.set(__self__, "timeouts", timeouts)
        if update_time is not None:
            pulumi.set(__self__, "update_time", update_time)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[str]]:
        """
        Timestamp of the creation of the organization.
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the organization.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> Optional[pulumi.Input[str]]:
        """
        Tenant ID of the organization.
        """
        return pulumi.get(self, "tenant_id")

    @tenant_id.setter
    def tenant_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "tenant_id", value)

    @property
    @pulumi.getter
    def timeouts(self) -> Optional[pulumi.Input['OrganizationTimeoutsArgs']]:
        return pulumi.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: Optional[pulumi.Input['OrganizationTimeoutsArgs']]):
        pulumi.set(self, "timeouts", value)

    @property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> Optional[pulumi.Input[str]]:
        """
        Timestamp of the last update of the organization.
        """
        return pulumi.get(self, "update_time")

    @update_time.setter
    def update_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "update_time", value)


class Organization(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 timeouts: Optional[pulumi.Input[Union['OrganizationTimeoutsArgs', 'OrganizationTimeoutsArgsDict']]] = None,
                 __props__=None):
        """
        Creates and manages an [organization](https://aiven.io/docs/platform/concepts/orgs-units-projects).

        ## Example Usage

        ```python
        import pulumi
        import pulumi_aiven as aiven

        main = aiven.Organization("main", name="Example organization")
        ```

        ## Import

        ```sh
        $ pulumi import aiven:index/organization:Organization main ORGANIZATION_ID
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] name: Name of the organization.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[OrganizationArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates and manages an [organization](https://aiven.io/docs/platform/concepts/orgs-units-projects).

        ## Example Usage

        ```python
        import pulumi
        import pulumi_aiven as aiven

        main = aiven.Organization("main", name="Example organization")
        ```

        ## Import

        ```sh
        $ pulumi import aiven:index/organization:Organization main ORGANIZATION_ID
        ```

        :param str resource_name: The name of the resource.
        :param OrganizationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(OrganizationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 timeouts: Optional[pulumi.Input[Union['OrganizationTimeoutsArgs', 'OrganizationTimeoutsArgsDict']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = OrganizationArgs.__new__(OrganizationArgs)

            __props__.__dict__["name"] = name
            __props__.__dict__["timeouts"] = timeouts
            __props__.__dict__["create_time"] = None
            __props__.__dict__["tenant_id"] = None
            __props__.__dict__["update_time"] = None
        super(Organization, __self__).__init__(
            'aiven:index/organization:Organization',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            create_time: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            tenant_id: Optional[pulumi.Input[str]] = None,
            timeouts: Optional[pulumi.Input[Union['OrganizationTimeoutsArgs', 'OrganizationTimeoutsArgsDict']]] = None,
            update_time: Optional[pulumi.Input[str]] = None) -> 'Organization':
        """
        Get an existing Organization resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] create_time: Timestamp of the creation of the organization.
        :param pulumi.Input[str] name: Name of the organization.
        :param pulumi.Input[str] tenant_id: Tenant ID of the organization.
        :param pulumi.Input[str] update_time: Timestamp of the last update of the organization.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _OrganizationState.__new__(_OrganizationState)

        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["name"] = name
        __props__.__dict__["tenant_id"] = tenant_id
        __props__.__dict__["timeouts"] = timeouts
        __props__.__dict__["update_time"] = update_time
        return Organization(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[str]:
        """
        Timestamp of the creation of the organization.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Name of the organization.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> pulumi.Output[str]:
        """
        Tenant ID of the organization.
        """
        return pulumi.get(self, "tenant_id")

    @property
    @pulumi.getter
    def timeouts(self) -> pulumi.Output[Optional['outputs.OrganizationTimeouts']]:
        return pulumi.get(self, "timeouts")

    @property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> pulumi.Output[str]:
        """
        Timestamp of the last update of the organization.
        """
        return pulumi.get(self, "update_time")

